@@ -7,7 +7,7 @@ from attr import define, field
 from crescent.utils.options import unwrap
 
 if TYPE_CHECKING:
-    from typing import Any, Awaitable, Callable, List, Optional, Sequence
+    from typing import Any, Awaitable, Callable, Sequence
 
     from crescent.bot import Bot
 
@@ -23,10 +23,10 @@ class MetaStruct(Generic[T, U]):
     callback: T
     metadata: U
 
-    manager: Optional[Any] = None
-    _app: Optional[Bot] = None
+    manager: Any | None = None
+    _app: Bot | None = None
 
-    app_set_hooks: List[Callable[[MetaStruct[T, U]], None]] = field(factory=list)
+    app_set_hooks: list[Callable[[MetaStruct[T, U]], None]] = field(factory=list)
     plugin_unload_hooks: list[Callable[[MetaStruct[T, U]], None]] = field(factory=list)
 
     @property
